#
# spec file for package mpfi
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mpfi
%define lname	libmpfi0
Version:        1.5.4
Release:        2.4
Summary:        Multi-precision floating-point interval arithmetic computation library
License:        LGPL-2.1-or-later
Group:          Productivity/Scientific/Math
URL:            https://gitlab.inria.fr/mpfi/mpfi
# gforge is gone and replaced by gitlab; tarballs apparently not retained
#Source:         https://gforge.inria.fr/frs/download.php/file/38111/mpfi-1.5.4.tgz
Source:         %name-%version.tgz
Patch1:         0001-incorret-types-corrected.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gmp-devel >= 4.1.0
BuildRequires:  libtool
BuildRequires:  makeinfo
BuildRequires:  mpfr-devel >= 3
BuildRequires:  pkgconfig
Requires(post): %install_info_prereq
Requires(postun): %install_info_prereq

%description
MPFI is a C library for arbitrary precision interval arithmetic with
intervals represented using MPFR reliable floating-point numbers.

The purpose of an arbitrary precision interval arithmetic is on the
one hand to get "guaranteed" results, thanks to interval computation,
and on the other hand to obtain accurate results, thanks to multiple
precision arithmetic.

%package -n %lname
Summary:        Multi-precision floating-point interval arithmetic computation library
Group:          System/Libraries

%description -n %lname
MPFI is a C library for arbitrary precision interval arithmetic with
intervals represented using MPFR reliable floating-point numbers.

The purpose of an arbitrary precision interval arithmetic is on the
one hand to get "guaranteed" results, thanks to interval computation,
and on the other hand to obtain accurate results, thanks to multiple
precision arithmetic.

%package devel
Summary:        Development files for the MPFI interval arithmetic computation library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
MPFI is a C library for arbitrary precision interval arithmetic with
intervals represented using MPFR reliable floating-point numbers.

This subpackage provides the development headers and libraries for it.

%prep
%autosetup -p1

%build
./autogen.sh
%configure --disable-static
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%check
#make check #upstream broke it in 1.5.4

%ldconfig_scriptlets -n %lname

%post devel
%install_info --info-dir="%_infodir" "%_infodir/mpfi.info.gz"

%postun devel
%install_info_delete --info-dir="%_infodir" "%_infodir/mpfi.info.gz"

%files -n %lname
%_libdir/libmpfi.so.0*

%files devel
%_includedir/mpfi*.h
%_libdir/libmpfi.so
%_infodir/mpfi.info*
%license COPYING*

%changelog
* Sat Nov  2 2024 Jan Engelhardt <jengelh@inai.de>
- Add 0001-incorret-types-corrected.patch
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.5.4
  * mp_exp_t replaced by mpfr_exp_t, mp_prec_t replaced by
    mpfr_prec_t, mp_rnd_t replaced by mpfr_rnd_t GMP_RNDx
    replaced by MPFR_RNDx.
* Fri Jan 19 2018 jengelh@inai.de
- Update to new upstream release 1.5.3
  * be compatible with MPFR version 4.0.0
- Changes introduced with 1.5.2
  * fix documentation of comparison functions
  * fix bug in mpfi_sub_fr
  * new symbols MPFI_VERSION_MAJOR, MPFI_VERSION_MINOR,
    MPFI_VERSION_PATCHLEVEL, and MPFI_VERSION_STRING in mpfi.h
  * detect availability of mpfr_z_sub, mpfr_z_div, and mpfr_q_sub
    and use a custom implementation for the ones not provided by
    MPFR (mpfr_z_sub appeared in MPFR 3.1.0, the other ones are
    used in tests only)
  * tadd_q does no more check overflow by default (required too
    much memory)
  * sign of zeros choice documented
* Thu Dec 13 2012 jengelh@inai.de
- Initial package (version 1.5.1) for build.opensuse.org
